==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__mesh_8h.js <==
var cs__mesh_8h =
[
    [ "cs_mesh_t", "structcs__mesh__t.html", "structcs__mesh__t" ],
    [ "CS_MESH_MODIFIED", "cs__mesh_8h.html#af6a4bb9524596193befa2cc162927719", null ],
    [ "CS_MESH_MODIFIED_BALANCE", "cs__mesh_8h.html#aa1d0378c18cade7ddefb54cb60085a61", null ],
    [ "cs_mesh_time_dep_t", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90", [
      [ "CS_MESH_FIXED", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90a912a2294f5378d40fcaf008e70c9ca2e", null ],
      [ "CS_MESH_TRANSIENT_COORDS", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90a4980e50f87d877897ea4de45c0219dc1", null ],
      [ "CS_MESH_TRANSIENT_CONNECT", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90a64fdd0b5fe6a11e81a59bbe8791c36c6", null ]
    ] ],
    [ "cs_mesh_b_faces_thread_block_count", "cs__mesh_8h.html#a9a0948d35a2951d5c74e8e567d62a498", null ],
    [ "cs_mesh_b_faces_thread_block_range", "cs__mesh_8h.html#adb6c55af313a347953be3d3579d44587", null ],
    [ "cs_mesh_clean_families", "cs__mesh_8h.html#a31961de07f4c0a3655dad68de46d83cc", null ],
    [ "cs_mesh_compact_gnum", "cs__mesh_8h.html#ad2cede98daacb0339f90f22fce4a422d", null ],
    [ "cs_mesh_create", "cs__mesh_8h.html#a3033959e75fb3880314c76ec249a0c0c", null ],
    [ "cs_mesh_create_group_classes", "cs__mesh_8h.html#a767bcbfa6800eb960e4e6bda13cbfb9d", null ],
    [ "cs_mesh_destroy", "cs__mesh_8h.html#ab109f198da5a3c0344b904e9966fb861", null ],
    [ "cs_mesh_discard_free_faces", "cs__mesh_8h.html#a7012d00b37dfafd88f72e57cb51ddee6", null ],
    [ "cs_mesh_discard_free_vertices", "cs__mesh_8h.html#a12a8e7ceb2c1e0d18b589d14df4e3381", null ],
    [ "cs_mesh_discard_refinement_info", "cs__mesh_8h.html#a1c15920d47e9f6a851673de67707663d", null ],
    [ "cs_mesh_dump", "cs__mesh_8h.html#a729d38a629ca1cdcca20532bf008875d", null ],
    [ "cs_mesh_free_rebuildable", "cs__mesh_8h.html#a0254819431b37826e6d368edb977773f", null ],
    [ "cs_mesh_g_face_vertices_sizes", "cs__mesh_8h.html#af4d5af6eee76cdcc27039dd1bd0ae353", null ],
    [ "cs_mesh_get_cell_gnum", "cs__mesh_8h.html#a310bcd6d465d27e5fbf7be18cd0f80a7", null ],
    [ "cs_mesh_get_face_perio_num", "cs__mesh_8h.html#a18b225be48119145eee3fc51d40caccc", null ],
    [ "cs_mesh_get_perio_faces", "cs__mesh_8h.html#aaf1f59a4697d2bd85f86546e920e7d39", null ],
    [ "cs_mesh_i_faces_thread_block_count", "cs__mesh_8h.html#a467a7e0a570be9bf19c58742ed8fb70f", null ],
    [ "cs_mesh_i_faces_thread_block_range", "cs__mesh_8h.html#a58b1ee6bd04a0d043cabcda8ec478099", null ],
    [ "cs_mesh_init_group_classes", "cs__mesh_8h.html#afa1c73c87581c379ef8ee2e6fd1cd460", null ],
    [ "cs_mesh_init_halo", "cs__mesh_8h.html#a4e677629662170d56ddf71b4c00b6ec8", null ],
    [ "cs_mesh_init_interfaces", "cs__mesh_8h.html#aada38b445454ecbde56dc4dbd854bc3d", null ],
    [ "cs_mesh_init_selectors", "cs__mesh_8h.html#ae2d5f5a4b2e0a9af607e05e753c13ace", null ],
    [ "cs_mesh_n_g_ghost_cells", "cs__mesh_8h.html#aad7481cca576fd24cf66bc8d20c6fb29", null ],
    [ "cs_mesh_print_info", "cs__mesh_8h.html#ae7f86ecb6cdb581181aef0cd3e10dba0", null ],
    [ "cs_mesh_reinit", "cs__mesh_8h.html#a860afc01fa2b741f68773f2671c756b9", null ],
    [ "cs_mesh_selector_stats", "cs__mesh_8h.html#a4c4513d4e71b895875eddb5e977a790d", null ],
    [ "cs_mesh_sync_var_scal", "cs__mesh_8h.html#ae0fcf6166267b6d6f0e4daaaa16d9ad7", null ],
    [ "cs_mesh_sync_var_scal_ext", "cs__mesh_8h.html#a3681b2feeeb47f589f293cd498e83157", null ],
    [ "cs_mesh_sync_var_sym_tens", "cs__mesh_8h.html#a5008c0bfd63ccd6ef5923368491ffd80", null ],
    [ "cs_mesh_sync_var_tens", "cs__mesh_8h.html#a831fab33aab00280e3c0d3848349e634", null ],
    [ "cs_mesh_sync_var_vect", "cs__mesh_8h.html#ae186eff3df8963dfc3a0ee8efd5baac0", null ],
    [ "cs_mesh_sync_var_vect_ext", "cs__mesh_8h.html#a0910f3b55252b623c90314f3bd6de581", null ],
    [ "cs_mesh_tag_boundary_cells", "cs__mesh_8h.html#a59926a8e9284c0677ee1d1022d6c2f4b", null ],
    [ "cs_mesh_update_auxiliary", "cs__mesh_8h.html#a3213cf9718ca240d9363d1d948c69db9", null ],
    [ "cs_mesh_update_b_cells", "cs__mesh_8h.html#a21fd28099760264cd5b24497a7961740", null ],
    [ "cs_mesh_update_selectors", "cs__mesh_8h.html#ad420d5ae2e8a3eb5e10b2e4f5b47d9f8", null ],
    [ "synsca", "cs__mesh_8h.html#af15d3939189210a889370f71c98fbd63", null ],
    [ "synsce", "cs__mesh_8h.html#a25c83c20b36c7d829a19cf22d2982b25", null ],
    [ "syntin", "cs__mesh_8h.html#a59fca633b520e01fa070219b357a838a", null ],
    [ "syntis", "cs__mesh_8h.html#a17df54edc415a6bc04a421b3e71d3a30", null ],
    [ "synvie", "cs__mesh_8h.html#a4950da12c3bf47b4ea9229f8a4eb5f1d", null ],
    [ "synvin", "cs__mesh_8h.html#afc01def48742089ed47a5f10882af5c7", null ],
    [ "cs_glob_mesh", "cs__mesh_8h.html#ab940dea1247a52efb9a4ef46d1e18921", null ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__mesh_8h.js <==
var cs__mesh_8h =
[
    [ "cs_mesh_t", "structcs__mesh__t.html", "structcs__mesh__t" ],
    [ "CS_MESH_MODIFIED", "cs__mesh_8h.html#af6a4bb9524596193befa2cc162927719", null ],
    [ "CS_MESH_MODIFIED_BALANCE", "cs__mesh_8h.html#aa1d0378c18cade7ddefb54cb60085a61", null ],
    [ "cs_mesh_time_dep_t", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90", [
      [ "CS_MESH_FIXED", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90a912a2294f5378d40fcaf008e70c9ca2e", null ],
      [ "CS_MESH_TRANSIENT_COORDS", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90a4980e50f87d877897ea4de45c0219dc1", null ],
      [ "CS_MESH_TRANSIENT_CONNECT", "cs__mesh_8h.html#ace1feea8c76eb075c06b0d357e660f90a64fdd0b5fe6a11e81a59bbe8791c36c6", null ]
    ] ],
    [ "cs_mesh_clean_families", "cs__mesh_8h.html#a31961de07f4c0a3655dad68de46d83cc", null ],
    [ "cs_mesh_compact_gnum", "cs__mesh_8h.html#ad2cede98daacb0339f90f22fce4a422d", null ],
    [ "cs_mesh_create", "cs__mesh_8h.html#a02f46fe09402a94ac46311ef89c04a47", null ],
    [ "cs_mesh_create_group_classes", "cs__mesh_8h.html#a6d4e198dd05c6558f335f12e7c9c9e07", null ],
    [ "cs_mesh_destroy", "cs__mesh_8h.html#abfa571d1aed141236c6b2fb365a61642", null ],
    [ "cs_mesh_discard_free_faces", "cs__mesh_8h.html#a7012d00b37dfafd88f72e57cb51ddee6", null ],
    [ "cs_mesh_discard_free_vertices", "cs__mesh_8h.html#a12a8e7ceb2c1e0d18b589d14df4e3381", null ],
    [ "cs_mesh_discard_refinement_info", "cs__mesh_8h.html#a1c15920d47e9f6a851673de67707663d", null ],
    [ "cs_mesh_dump", "cs__mesh_8h.html#a729d38a629ca1cdcca20532bf008875d", null ],
    [ "cs_mesh_free_b_rebuildable", "cs__mesh_8h.html#a4d684c4768d2359eb41dac775ab17d9d", null ],
    [ "cs_mesh_free_rebuildable", "cs__mesh_8h.html#a0254819431b37826e6d368edb977773f", null ],
    [ "cs_mesh_g_face_vertices_sizes", "cs__mesh_8h.html#af4d5af6eee76cdcc27039dd1bd0ae353", null ],
    [ "cs_mesh_get_cell_gnum", "cs__mesh_8h.html#ad5ef36c0fefce00c5491ce50186527bf", null ],
    [ "cs_mesh_get_face_perio_num", "cs__mesh_8h.html#a18b225be48119145eee3fc51d40caccc", null ],
    [ "cs_mesh_get_perio_faces", "cs__mesh_8h.html#aaf1f59a4697d2bd85f86546e920e7d39", null ],
    [ "cs_mesh_i_faces_thread_block_count", "cs__mesh_8h.html#a467a7e0a570be9bf19c58742ed8fb70f", null ],
    [ "cs_mesh_i_faces_thread_block_range", "cs__mesh_8h.html#a58b1ee6bd04a0d043cabcda8ec478099", null ],
    [ "cs_mesh_init_b_selector", "cs__mesh_8h.html#a39b0b01d32336c3afff6e214d783fb5c", null ],
    [ "cs_mesh_init_cell_selector", "cs__mesh_8h.html#a0d3dd42dccc0abbe318a1276416df5f6", null ],
    [ "cs_mesh_init_group_classes", "cs__mesh_8h.html#afa1c73c87581c379ef8ee2e6fd1cd460", null ],
    [ "cs_mesh_init_halo", "cs__mesh_8h.html#a4e677629662170d56ddf71b4c00b6ec8", null ],
    [ "cs_mesh_init_i_selector", "cs__mesh_8h.html#a97cdf41a6daa5a7a514decc1ca353550", null ],
    [ "cs_mesh_init_interfaces", "cs__mesh_8h.html#aada38b445454ecbde56dc4dbd854bc3d", null ],
    [ "cs_mesh_init_selectors", "cs__mesh_8h.html#ae2d5f5a4b2e0a9af607e05e753c13ace", null ],
    [ "cs_mesh_n_g_ghost_cells", "cs__mesh_8h.html#aad7481cca576fd24cf66bc8d20c6fb29", null ],
    [ "cs_mesh_print_element_counts", "cs__mesh_8h.html#a1bb499b509c1945a19f6a2de404ab1ac", null ],
    [ "cs_mesh_print_info", "cs__mesh_8h.html#ae7f86ecb6cdb581181aef0cd3e10dba0", null ],
    [ "cs_mesh_reinit", "cs__mesh_8h.html#a860afc01fa2b741f68773f2671c756b9", null ],
    [ "cs_mesh_selector_stats", "cs__mesh_8h.html#a4c4513d4e71b895875eddb5e977a790d", null ],
    [ "cs_mesh_sync_var_scal", "cs__mesh_8h.html#ae0fcf6166267b6d6f0e4daaaa16d9ad7", null ],
    [ "cs_mesh_tag_boundary_cells", "cs__mesh_8h.html#a59926a8e9284c0677ee1d1022d6c2f4b", null ],
    [ "cs_mesh_update_auxiliary", "cs__mesh_8h.html#a3213cf9718ca240d9363d1d948c69db9", null ],
    [ "cs_mesh_update_b_cells", "cs__mesh_8h.html#a21fd28099760264cd5b24497a7961740", null ],
    [ "cs_mesh_update_selectors", "cs__mesh_8h.html#ad420d5ae2e8a3eb5e10b2e4f5b47d9f8", null ],
    [ "cs_glob_mesh", "cs__mesh_8h.html#ab940dea1247a52efb9a4ef46d1e18921", null ]
];
